@@ -2,7 +2,7 @@ package Class::Method::Modifiers;
 use strict;
 use warnings;
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 use base 'Exporter';
 our @EXPORT = qw(before after around);
@@ -72,9 +72,7 @@ sub install_modifier {
         # the Moose equivalent. :)
         if ($type eq 'around') {
             my $method = $cache->{wrapped};
-            $cache->{wrapped} = sub {
-                $code->($method, @_);
-            };
+            $cache->{wrapped} = eval "package $into; sub { \$code->(\$method, \@_); };";
         }
 
         # install our new method which dispatches the modifiers, but only
@@ -89,7 +87,8 @@ sub install_modifier {
             # to take a reference to it. better a deref than a hash lookup
             my $wrapped = \$cache->{"wrapped"};
 
-            my $generated = 'sub {';
+            my $generated = "package $into;\n";
+            $generated .= "sub $name {";
 
             # before is easy, it doesn't affect the return value(s)
             $generated .= '$_->(@_) for @$before;' if @$before;
@@ -120,7 +119,7 @@ sub install_modifier {
 
             no strict 'refs';
             no warnings 'redefine';
-            *$qualified = eval $generated;
+            eval $generated;
         };
     }
 }
